@@ -29,15 +29,15 @@
 #define REPLAY_WINDOW_SIZE 64
 
 
-const int SrtpAuthenticationNull     =  0;
-const int SrtpAuthenticationSha1Hmac =  1;
-const int SrtpAuthenticationSkeinHmac = 2;
-
-const int SrtpEncryptionNull  = 0;
-const int SrtpEncryptionAESCM = 1;
-const int SrtpEncryptionAESF8 = 2;
-const int SrtpEncryptionTWOCM = 3;
-const int SrtpEncryptionTWOF8 = 4;
+// const int SrtpAuthenticationNull     =  0;
+// const int SrtpAuthenticationSha1Hmac =  1;
+// const int SrtpAuthenticationSkeinHmac = 2;
+// 
+// const int SrtpEncryptionNull  = 0;
+// const int SrtpEncryptionAESCM = 1;
+// const int SrtpEncryptionAESF8 = 2;
+// const int SrtpEncryptionTWOCM = 3;
+// const int SrtpEncryptionTWOF8 = 4;
 
 #ifdef SRTP_SUPPORT
 #include <ccrtp/crypto/AesSrtp.h>
